==> bareos_14.2.6.orig.tar.gz: bareos-Release-14.2.6/src/stored/backends/unix_fifo_device.h <==
/*
   BAREOS® - Backup Archiving REcovery Open Sourced

   Copyright (C) 2013-2013 Bareos GmbH & Co. KG

   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version three of the GNU Affero General Public
   License as published by the Free Software Foundation, which is
   listed in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Affero General Public License for more details.

   You should have received a copy of the GNU Affero General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/
/*
 * UNIX File API device abstraction.
 *
 * Marco van Wieringen, June 2014
 */

#ifndef UNIX_FIFO_DEVICE_H
#define UNIX_FIFO_DEVICE_H

class unix_fifo_device: public DEVICE {
public:
   unix_fifo_device();
   ~unix_fifo_device();

   /*
    * Interface from DEVICE
    */
   void open_device(DCR *dcr, int omode);
   bool eod(DCR *dcr);
   bool mount_backend(DCR *dcr, int timeout);
   bool unmount_backend(DCR *dcr, int timeout);
   int d_close(int);
   int d_open(const char *pathname, int flags, int mode);
   int d_ioctl(int fd, ioctl_req_t request, char *mt = NULL);
   boffset_t d_lseek(DCR *dcr, boffset_t offset, int whence);
   ssize_t d_read(int fd, void *buffer, size_t count);
   ssize_t d_write(int fd, const void *buffer, size_t count);
   bool d_truncate(DCR *dcr);
};
#endif /* UNIX_FIFO_DEVICE_H */

==> bareos_16.2.4.orig.tar.gz: bareos-Release-16.2.4/src/stored/backends/unix_fifo_device.h <==
/*
   BAREOS® - Backup Archiving REcovery Open Sourced

   Copyright (C) 2013-2013 Planets Communications B.V.
   Copyright (C) 2013-2013 Bareos GmbH & Co. KG

   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version three of the GNU Affero General Public
   License as published by the Free Software Foundation, which is
   listed in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Affero General Public License for more details.

   You should have received a copy of the GNU Affero General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/
/*
 * UNIX FIFO API device abstraction.
 *
 * Marco van Wieringen, June 2014
 */

#ifndef UNIX_FIFO_DEVICE_H
#define UNIX_FIFO_DEVICE_H

class unix_fifo_device: public DEVICE {
public:
   unix_fifo_device();
   ~unix_fifo_device();

   /*
    * Interface from DEVICE
    */
   void open_device(DCR *dcr, int omode);
   bool eod(DCR *dcr);
   bool mount_backend(DCR *dcr, int timeout);
   bool unmount_backend(DCR *dcr, int timeout);
   int d_close(int);
   int d_open(const char *pathname, int flags, int mode);
   int d_ioctl(int fd, ioctl_req_t request, char *mt = NULL);
   boffset_t d_lseek(DCR *dcr, boffset_t offset, int whence);
   ssize_t d_read(int fd, void *buffer, size_t count);
   ssize_t d_write(int fd, const void *buffer, size_t count);
   bool d_truncate(DCR *dcr);
};
#endif /* UNIX_FIFO_DEVICE_H */
